import { ref } from 'vue'
import { defineStore } from 'pinia'

export const useAssetManagerStore = defineStore('assetManager', () => {
  const tileList = ref<string[]>([])
  const objectList = ref<string[]>([])
  const selectedTile = ref<string | null>(null)
  const selectedObject = ref<string | null>(null)
  const objectDetails = ref<Record<string, any>>({})

  function setTileList(tiles: string[]) {
    tileList.value = tiles
  }

  function setObjectList(objects: string[]) {
    objectList.value = objects
  }

  function setSelectedTile(tile: string) {
    selectedTile.value = tile
  }

  function setSelectedObject(object: string) {
    selectedObject.value = object
  }

  function setObjectDetails(object: Record<string, any>) {
    objectDetails.value = object
  }

  function reset() {
    tileList.value = []
    selectedTile.value = null
    selectedObject.value = null
    objectDetails.value = {}
  }

  return {
    tileList,
    objectList,
    setTileList,
    setObjectList,
    selectedTile,
    selectedObject,
    setSelectedTile,
    setSelectedObject,
    objectDetails,
    setObjectDetails
  }
})
